## Description
Brief description of changes.

## Type of Change
- [ ] Bug fix
- [ ] New feature
- [ ] Documentation update
- [ ] Performance improvement
- [ ] Other (describe)

## Testing
- [ ] Tests pass locally
- [ ] New tests added (if applicable)
- [ ] Smoke test passes (130 tools)

## Checklist
- [ ] Code follows project style
- [ ] Documentation updated
- [ ] CHANGELOG updated (if user-facing)
- [ ] No sensitive data exposed

## Related Issues
Fixes #

## Screenshots (if applicable)
